Risk Distributions
======================

.. image:: https://badge.fury.io/py/risk_distributions.svg
    :target: https://badge.fury.io/py/risk_distributions

.. image:: https://travis-ci.org/ihmeuw/risk_distributions.svg?branch=master
    :target: https://travis-ci.org/ihmeuw/risk_distributions
    :alt: Latest Version

This library contains various distributions, compatible for use with ``Vivarium``.

You can install ``risk_distributions`` from PyPI with pip:

  ``> pip install risk_distributions``

or build it from source with

  ``> git clone https://github.com/ihmeuw/risk_distributions.git``

  ``> cd risk_distributions``

  ``> python setup.py install``


